#[repr(u32)]pub enum AccountResolutionError {
Show 20 variants
IncorrectAccount = 2_724_315_840,
NotEnoughAccounts = 2724315841,
TlvUninitialized = 2724315842,
TlvInitialized = 2724315843,
TooManyPubkeys = 2724315844,
InvalidPubkey = 2724315845,
AccountTypeNotAccountMeta = 2724315846,
SeedConfigsTooLarge = 2724315847,
NotEnoughBytesForSeed = 2724315848,
InvalidBytesForSeed = 2724315849,
InvalidSeedConfig = 2724315850,
InstructionDataTooSmall = 2724315851,
AccountNotFound = 2724315852,
CalculationFailure = 2724315853,
AccountDataNotFound = 2724315854,
AccountDataTooSmall = 2724315855,
AccountFetchFailed = 2724315856,
NotEnoughBytesForPubkeyData = 2724315857,
InvalidBytesForPubkeyData = 2724315858,
InvalidPubkeyDataConfig = 2724315859,
}Expand description
Errors that may be returned by the Account Resolution library.
Variants
IncorrectAccount = 2_724_315_840
Incorrect account provided
NotEnoughAccounts = 2724315841
Not enough accounts provided
TlvUninitialized = 2724315842
No value initialized in TLV data
TlvInitialized = 2724315843
Some value initialized in TLV data
TooManyPubkeys = 2724315844
Too many pubkeys provided
InvalidPubkey = 2724315845
Failed to parse Pubkey from bytes
AccountTypeNotAccountMeta = 2724315846
Attempted to deserialize an AccountMeta but the underlying type has
PDA configurations rather than a fixed address
SeedConfigsTooLarge = 2724315847
Provided list of seed configurations too large for a validation account
NotEnoughBytesForSeed = 2724315848
Not enough bytes available to pack seed configuration
InvalidBytesForSeed = 2724315849
The provided bytes are not valid for a seed configuration
InvalidSeedConfig = 2724315850
Tried to pack an invalid seed configuration
InstructionDataTooSmall = 2724315851
Instruction data too small for seed configuration
AccountNotFound = 2724315852
Could not find account at specified index
CalculationFailure = 2724315853
Error in checked math operation
AccountDataNotFound = 2724315854
Could not find account data at specified index
AccountDataTooSmall = 2724315855
Account data too small for requested seed configuration
AccountFetchFailed = 2724315856
Failed to fetch account
NotEnoughBytesForPubkeyData = 2724315857
Not enough bytes available to pack pubkey data configuration.
InvalidBytesForPubkeyData = 2724315858
The provided bytes are not valid for a pubkey data configuration
InvalidPubkeyDataConfig = 2724315859
Tried to pack an invalid pubkey data configuration